/***************************************************************************
                          job_appendsmbtodatabase.h  -  description
                             -------------------
    begin                : Mon Jun 4 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_APPENDSMBTODATABASE_H
#define JOB_APPENDSMBTODATABASE_H

#include "prokyon.h"

#include "jobbasetagmanipulation.h"

#include "lvi_smbshare.h"

class Job_AppendSMBToDatabase : public JobBaseTagManipulation  {
 public: 
  Job_AppendSMBToDatabase(LVI_SMBShare *_share);

  int type() { return JOB_APPEND_SMB_TO_DATABASE; }

  void run();

  ~Job_AppendSMBToDatabase();

 private:
  LVI_SMBShare *share;
};

#endif
